@@ -8,14 +8,15 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk._jsii
+import aws_cdk.aws_lambda._jsii
+import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-lambda-layer-curl",
-    "0.0.2",
+    "1.0.2",
     __name__[0:-6],
-    "cdk-lambda-layer-curl@0.0.2.jsii.tgz",
+    "cdk-lambda-layer-curl@1.0.2.jsii.tgz",
 )
 
 __all__ = [
